@@ -1,5 +1,11 @@
 from __future__ import print_function
 from __future__ import absolute_import
+
+try:
+    from urllib.request import urlopen
+except:
+    from urllib2 import urlopen
+
 from future import standard_library
 standard_library.install_aliases()
 from builtins import str
@@ -7,18 +13,12 @@ import argparse
 import os
 import subprocess
 import traceback
-import urllib.error, urllib.parse
 from . import utils
 import sys
 from shutil import copyfile
 from .agent import run_agent
 from time import sleep
 
-try:
-   from urllib.request import urlopen
-except ImportError:
-   from urllib2 import urlopen
-
 
 def main():
     s3_base_link = 'https://s3.amazonaws.com/spotinst-public/services/spotinst-agent'
