@@ -1,4 +1,12 @@
 from __future__ import print_function
+
+try:
+    from urllib.parse import quote
+    from urllib.request import Request, urlopen
+    from urllib.error import HTTPError, URLError
+except:
+    from urllib2 import Request, urlopen, HTTPError, URLError, quote
+
 from future import standard_library
 standard_library.install_aliases()
 from builtins import str
@@ -10,8 +18,6 @@ import os
 import sys
 from _ssl import SSLError
 from json import loads
-from urllib.request import Request, urlopen
-from urllib.error import HTTPError, URLError
 import yaml
 
 sys.path.append(os.path.abspath(os.path.join(os.path.dirname(__file__), "..")))
@@ -39,8 +45,9 @@ def safe_get_json(json_string, key, log=logging.getLogger('spotinst-agent')):
 
 def safe_read_simple_url(url, log=logging.getLogger('spotinst-agent')):
     try:
-        log.debug("reading simple {} ...".format(url))
-        req = Request(url)
+        quoteUrl = quote(url)
+        log.debug("reading simple {} ...".format(quoteUrl))
+        req = Request(quoteUrl)
         req.add_header('Content-Type', 'application/json')
         response = urlopen(req, timeout=10)
         return response.read().decode('utf-8')
@@ -59,8 +66,9 @@ def safe_read_simple_url(url, log=logging.getLogger('spotinst-agent')):
 def get_gcp_metadata(url, path_params, log=logging.getLogger('spotinst-agent')):
     try:
         url = url + path_params
-        log.debug("reading simple {} ...".format(url))
-        req = Request(url)
+        quoteUrl = quote(url)
+        log.debug("reading simple {} ...".format(quoteUrl))
+        req = Request(quoteUrl)
         #req.add_header('Content-Type', 'application/json')
         req.add_header('Metadata-Flavor','Google')
         response = urlopen(req, timeout=10)
@@ -80,8 +88,9 @@ def get_gcp_metadata(url, path_params, log=logging.getLogger('spotinst-agent')):
 # getting vmId - not whole the metadata
 def get_azure_metadata(url, log=logging.getLogger('spotinst-agent')):
     try:
-        log.debug("reading simple {} ...".format(url))
-        req = Request(url)
+        quoteUrl = quote(url)
+        log.debug("reading simple {} ...".format(quoteUrl))
+        req = Request(quoteUrl)
         req.add_header('Metadata', 'true')
         response = urlopen(req, timeout=10)
         return response.read().decode('utf-8')
@@ -100,8 +109,9 @@ def get_azure_metadata(url, log=logging.getLogger('spotinst-agent')):
 
 def safe_get_simple_url(url, log=logging.getLogger('spotinst-agent')):
     try:
-        log.debug("reading simple {} ...".format(url))
-        req = Request(url)
+        quoteUrl = quote(url)
+        log.debug("reading simple {} ...".format(quoteUrl))
+        req = Request(quoteUrl)
         req.add_header('Content-Type', 'application/json')
         response = urlopen(req, timeout=5)
         res = response.read()
@@ -121,8 +131,9 @@ def safe_get_simple_url(url, log=logging.getLogger('spotinst-agent')):
 
 def safe_get_url(url, token=None, log=logging.getLogger('spotinst-agent')):
     try:
-        log.debug("getting {} ...".format(url))
-        req = Request(url)
+        quoteUrl = quote(url)
+        log.debug("getting {} ...".format(quoteUrl))
+        req = Request(quoteUrl)
         req.add_header('Content-Type', 'application/json')
         if token:  # add token
             req.add_header('Authorization', 'Bearer ' + token)
@@ -148,10 +159,11 @@ def safe_get_url(url, token=None, log=logging.getLogger('spotinst-agent')):
 
 def safe_post_url(url, message, token=None, log=logging.getLogger('spotinst-agent')):
     try:
-        log.info("posting {} ...".format(url))
+        quoteUrl = quote(url)
+        log.info("posting {} ...".format(quoteUrl))
         log.info("token is " + token)
         data = message.encode('utf-8')
-        req = Request(url)
+        req = Request(quoteUrl)
         req.add_header('Content-Type', 'application/json')
         if token:  # add token
             req.add_header('Authorization', 'Bearer ' + token)
@@ -179,9 +191,10 @@ def safe_post_url(url, message, token=None, log=logging.getLogger('spotinst-agen
 
 def safe_put_url(url, message, token, log=logging.getLogger('spotinst-agent')):
     try:
-        log.debug("putting %s ..." % url)
+        quoteUrl = quote(url)
+        log.debug("putting %s ..." % quoteUrl)
         data = message.encode('utf-8')
-        req = Request(url)
+        req = Request(quoteUrl)
         req.add_header('Content-Type', 'application/json')
         if token:  # add token
             req.add_header('Authorization', 'Bearer ' + token)
